@@ -127,7 +127,6 @@ class Director(object):
             log.msg("Connecting to Tor Control Port...")
             yield self.getTorState()
 
-        config.probe_ip = geoip.ProbeIP()
         yield config.probe_ip.lookup()
 
     @property
@@ -209,7 +208,6 @@ class Director(object):
         self.activeNetTests.remove(net_test)
         if len(self.activeNetTests) == 0:
             self.allTestsDone.callback(None)
-            self.allTestsDone = defer.Deferred()
 
     @defer.inlineCallbacks
     def startNetTest(self, net_test_loader, reporters):
@@ -220,9 +218,12 @@ class Director(object):
             net_test_loader:
                 an instance of :class:ooni.nettest.NetTestLoader
         """
+        if self.allTestsDone.called:
+            self.allTestsDone = defer.Deferred()
+
         if config.privacy.includepcap:
             if not config.reports.pcap:
-                config.reports.pcap = config.generatePcapFilename(net_test_loader.testDetails)
+                config.reports.pcap = config.generate_pcap_filename(net_test_loader.testDetails)
             self.startSniffing()
 
         report = Report(reporters, self.reportEntryManager)
