@@ -138,7 +138,7 @@ class NetTestLoader(object):
     requiresTor = False
 
     def __init__(self, options, test_file=None, test_string=None):
-        self.onionInputRegex =  re.compile("(httpo://[a-z0-9]{16}\.onion)/input/([a-z0-9]{64})$")
+        self.onionInputRegex = re.compile("(httpo://[a-z0-9]{16}\.onion)/input/([a-z0-9]{64})$")
         self.options = options
         self.testCases = []
 
@@ -185,10 +185,13 @@ class NetTestLoader(object):
                     input_file['hash'] = m.group(2)
                 else:
                     input_file['filename'] = filename
-                    with open(filename) as f:
-                        h = sha256()
-                        for l in f:
-                            h.update(l)
+                    try:
+                        with open(filename) as f:
+                            h = sha256()
+                            for l in f:
+                                h.update(l)
+                    except:
+                        raise e.InvalidInputFile(filename)
                     input_file['hash'] = h.hexdigest()
                 input_files.append(input_file)
 
@@ -198,45 +201,15 @@ class NetTestLoader(object):
     def testDetails(self):
         from ooni import __version__ as software_version
 
-        client_geodata = {
-                'city': None, 
-                'countrycode': 'ZZ',
-                'asn': 'AS0',
-                'ip': '127.0.0.1'
-        }
-
-        if config.probe_ip and config.probe_ip.address and (config.privacy.includeip or \
-                config.privacy.includeasn or \
-                config.privacy.includecountry or \
-                config.privacy.includecity):
-            log.msg("We will include some geo data in the report")
-            client_geodata = geoip.IPToLocation(config.probe_ip.address)
-
-        if config.privacy.includeip:
-            client_geodata['ip'] = config.probe_ip.address
-        else:
-            client_geodata['ip'] = "127.0.0.1"
-
-        # Here we unset all the client geodata if the option to not include then
-        # has been specified
-        if not config.privacy.includeasn:
-            client_geodata['asn'] = 'AS0'
-
-        if not config.privacy.includecity:
-            client_geodata['city'] = None
-
-        if not config.privacy.includecountry:
-            client_geodata['countrycode'] = None
-        
         input_file_hashes = []
         for input_file in self.inputFiles:
             input_file_hashes.append(input_file['hash'])
 
         test_details = {'start_time': time.time(),
-            'probe_asn': client_geodata['asn'],
-            'probe_cc': client_geodata['countrycode'],
-            'probe_ip': client_geodata['ip'],
-            'probe_city': client_geodata['city'],
+            'probe_asn': config.probe_ip.geodata['asn'],
+            'probe_cc': config.probe_ip.geodata['countrycode'],
+            'probe_ip': config.probe_ip.geodata['ip'],
+            'probe_city': config.probe_ip.geodata['city'],
             'test_name': self.testName,
             'test_version': self.testVersion,
             'software_name': 'ooniprobe',
@@ -320,7 +293,7 @@ class NetTestLoader(object):
 
         if not test_cases:
             raise e.NoTestCasesFound
-
+        
         self.setupTestCases(test_cases)
 
     def setupTestCases(self, test_cases):
@@ -356,10 +329,6 @@ class NetTestLoader(object):
         """
         Call processTest and processOptions methods of each NetTestCase
         """
-        test_classes = set([])
-        for test_class, test_method in self.testCases:
-            test_classes.add(test_class)
-
         for klass in self.testClasses:
             options = self.usageOptions()
             options.parseOptions(self.options)
@@ -372,6 +341,7 @@ class NetTestLoader(object):
                 checkForRoot()
             if test_instance.requiresTor:
                 self.requiresTor = True
+            test_instance.requirements()
             test_instance._checkRequiredOptions()
             test_instance._checkValidOptions()
 
@@ -470,6 +440,8 @@ class NetTest(object):
         return ' '.join(tc.name for tc, _ in self.testCases)
     
     def doneNetTest(self, result):
+        if not self.summary:
+            return
         print "Summary for %s" % self.testDetails['test_name']
         print "------------" + "-"*len(self.testDetails['test_name'])
         for test_class in self.testClasses:
@@ -642,6 +614,13 @@ class NetTestCase(object):
         """
         self.report = {}
         self.inputs = None
+    
+    def requirements(self):
+        """
+        Place in here logic that will be executed before the test is to be run.
+        If some condition is not met then you should raise an exception.
+        """
+        pass
 
     def setUp(self):
         """
