@@ -10,7 +10,7 @@ from twisted.internet import reactor
 from twisted.python import usage
 from twisted.python.util import spewer
 
-from ooni import errors
+from ooni import errors, __version__
 
 from ooni.settings import config
 from ooni.director import Director
@@ -32,7 +32,8 @@ class Options(usage.Options):
                 ["resume", "r"],
                 ["no-collector", "n"],
                 ["list", "s"],
-                ["printdeck", "p"]
+                ["printdeck", "p"],
+                ["verbose", "v"]
                 ]
 
     optParameters = [["reportfile", "o", None, "report file name"],
@@ -68,6 +69,13 @@ class Options(usage.Options):
         """
         sys.settrace(spewer)
 
+    def opt_version(self):
+        """
+        Display the ooniprobe version and exit.
+        """
+        print "ooniprobe version:", __version__
+        sys.exit(0)
+
     def parseArgs(self, *args):
         if self['testdeck'] or self['list']:
             return
@@ -80,7 +88,7 @@ class Options(usage.Options):
 def parseOptions():
     print "WARNING: running ooniprobe involves some risk that varies greatly"
     print "         from country to country. You should be aware of this when"
-    print "         running the tool. Read more about this in the README."
+    print "         running the tool. Read more about this in the manpage or README."
     cmd_line_options = Options()
     if len(sys.argv) == 1:
         cmd_line_options.getUsage()
@@ -100,19 +108,22 @@ def runWithDirector(logging=True, start_tor=True):
     global_options = parseOptions()
     config.global_options = global_options
     config.set_paths()
+    config.initialize_ooni_home()
     config.read_config_file()
+    if global_options['verbose']:
+        config.advanced.debug = True
     if not start_tor:
         config.advanced.start_tor = False
-    
+
     if logging:
         log.start(global_options['logfile'])
-    
+
     if config.privacy.includepcap:
         try:
             checkForRoot()
         except errors.InsufficientPrivileges:
              log.err("Insufficient Privileges to capture packets."
-                     " See ooniprobe.conf privacy.includepcap") 
+                     " See ooniprobe.conf privacy.includepcap")
              sys.exit(2)
 
     director = Director()
@@ -120,12 +131,12 @@ def runWithDirector(logging=True, start_tor=True):
         print "# Installed nettests"
         for net_test_id, net_test in director.getNetTests().items():
             print "* %s (%s/%s)" % (net_test['name'],
-                                    net_test['category'], 
+                                    net_test['category'],
                                     net_test['id'])
             print "  %s" % net_test['description']
 
         sys.exit(0)
-    
+
     elif global_options['printdeck']:
         del global_options['printdeck']
         print "# Copy and paste the lines below into a test deck to run the specified test with the specified arguments"
@@ -152,7 +163,7 @@ def runWithDirector(logging=True, start_tor=True):
             deck.loadDeck(global_options['testdeck'])
         else:
             log.debug("No test deck detected")
-            test_file = nettest_to_path(global_options['test_file'])
+            test_file = nettest_to_path(global_options['test_file'], True)
             net_test_loader = NetTestLoader(global_options['subargs'],
                     test_file=test_file)
             deck.insert(net_test_loader)
@@ -166,10 +177,13 @@ def runWithDirector(logging=True, start_tor=True):
     except usage.UsageError, e:
         log.err(e)
         print net_test_loader.usageOptions().getUsage()
-        sys.exit(2)
-    
+        sys.exit(4)
+    except Exception as e:
+        log.err(e)
+        sys.exit(5)
+
     d = director.start(start_tor=start_tor)
-   
+
     def setup_nettest(_):
         try:
             return deck.setup()
@@ -181,7 +195,8 @@ def runWithDirector(logging=True, start_tor=True):
         r = failure.trap(errors.TorNotRunning,
                 errors.InvalidOONIBCollectorAddress,
                 errors.UnableToLoadDeckInput, errors.CouldNotFindTestHelper,
-                errors.CouldNotFindTestCollector, errors.ProbeIPUnknown)
+                errors.CouldNotFindTestCollector, errors.ProbeIPUnknown,
+                errors.InvalidInputFile)
 
         if isinstance(failure.value, errors.TorNotRunning):
             log.err("Tor does not appear to be running")
@@ -210,11 +225,13 @@ def runWithDirector(logging=True, start_tor=True):
             log.err("Failed to lookup probe IP address.")
             log.msg("Check your internet connection.")
 
+        elif isinstance(failure.value, errors.InvalidInputFile):
+            log.err("Invalid input file \"%s\"" % failure.value)
+
+        # XXX debug why we never reach this if exception is not trapped.
         if config.advanced.debug:
             log.exception(failure)
 
-        reactor.stop()
-
     # Wait until director has started up (including bootstrapping Tor)
     # before adding tests
     def post_director_start(_):
@@ -232,8 +249,8 @@ def runWithDirector(logging=True, start_tor=True):
             if not global_options['no-collector']:
                 if global_options['collector']:
                     collector = global_options['collector']
-                elif config.reports['collector']:
-                    collector = config.report['collector']
+                elif 'collector' in config.reports and config.reports['collector']:
+                    collector = config.reports['collector']
                 elif net_test_loader.collector:
                     collector = net_test_loader.collector
 
