@@ -3,15 +3,14 @@ import sys
 import yaml
 import getpass
 
-from shutil import copyfile
 from os.path import abspath, expanduser
 
-from twisted.internet import reactor, threads, defer
-
-from ooni import otime
+from ooni import otime, geoip
 from ooni.utils import Storage
 
 class OConfig(object):
+    _custom_home = None
+
     def __init__(self):
         self.current_user = getpass.getuser()
         self.global_options = {}
@@ -19,7 +18,7 @@ class OConfig(object):
         self.scapyFactory = None
         self.tor_state = None
         # This is used to store the probes IP address obtained via Tor
-        self.probe_ip = None
+        self.probe_ip = geoip.ProbeIP()
         # This is used to keep track of the state of the sniffer
         self.sniffer_running = None
         self.logging = True
@@ -28,9 +27,11 @@ class OConfig(object):
         self.tor = Storage()
         self.privacy = Storage()
         self.set_paths()
-        self.initialize_ooni_home()
 
-    def set_paths(self):
+    def set_paths(self, ooni_home=None):
+        if ooni_home:
+            self._custom_home = ooni_home
+
         if self.global_options.get('datadir'):
             self.data_directory = abspath(expanduser(self.global_options['datadir']))
         elif self.advanced.get('data_dir'):
@@ -43,17 +44,25 @@ class OConfig(object):
         self.nettest_directory = abspath(os.path.join(__file__, '..', 'nettests'))
 
         self.ooni_home = os.path.join(expanduser('~'+self.current_user), '.ooni')
+        if self._custom_home:
+            self.ooni_home = self._custom_home
         self.inputs_directory = os.path.join(self.ooni_home, 'inputs')
         self.decks_directory = os.path.join(self.ooni_home, 'decks')
         self.reports_directory = os.path.join(self.ooni_home, 'reports')
 
         if self.global_options.get('configfile'):
             config_file = self.global_options['configfile']
+            self.config_file = expanduser(config_file)
         else:
-            config_file = os.path.join('~', '.ooni', 'ooniprobe.conf')
-        self.config_file = expanduser(config_file)
+            self.config_file = os.path.join(self.ooni_home, 'ooniprobe.conf')
+
+        if 'logfile' in self.basic:
+            self.basic.logfile = expanduser(self.basic.logfile.replace('~','~'+self.current_user))
+
+    def initialize_ooni_home(self, ooni_home=None):
+        if ooni_home:
+            self.set_paths(ooni_home)
 
-    def initialize_ooni_home(self):
         if not os.path.isdir(self.ooni_home):
             print "Ooni home directory does not exist."
             print "Creating it in '%s'." % self.ooni_home
@@ -66,13 +75,12 @@ class OConfig(object):
     def _create_config_file(self):
         sample_config_file = os.path.join(self.data_directory,
                                           'ooniprobe.conf.sample')
-        target_config_file = os.path.join(self.ooni_home,
-                                          'ooniprobe.conf')
+        target_config_file = self.config_file
         print "Creating it for you in '%s'." % target_config_file
         usr_share_path = '/usr/share'
         if hasattr(sys, 'real_prefix'):
             usr_share_path = os.path.abspath(os.path.join(sys.prefix, 'share'))
-        
+
         with open(sample_config_file) as f:
             with open(target_config_file, 'w+') as w:
                 for line in f:
@@ -95,7 +103,7 @@ class OConfig(object):
             config_file_contents = '\n'.join(f.readlines())
             configuration = yaml.safe_load(config_file_contents)
 
-            for setting in ['basic', 'advanced', 'privacy', 'tor']:
+            for setting in ['basic', 'reports', 'advanced', 'privacy', 'tor']:
                 try:
                     for k, v in configuration[setting].items():
                         getattr(self, setting)[k] = v
@@ -103,7 +111,7 @@ class OConfig(object):
                     pass
         self.set_paths()
 
-    def generatePcapFilename(self, testDetails):
+    def generate_pcap_filename(self, testDetails):
         test_name, start_time = testDetails['test_name'], testDetails['start_time']
         start_time = otime.epochToTimestamp(start_time)
         return "report-%s-%s.%s" % (test_name, start_time, "pcap")
